# [Django Datta Able](https://app-generator.dev/docs/products/django-libs/theme-datta-able.html)

Modern template for **Django Admin**, Auth Pages (registration included) crafted on top of **Datta Able Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Datta Able](https://app-generator.dev/docs/products/django-libs/theme-datta-able.html) - Documentation & Support Links
- [Django Datta Able Dashboard](https://app-generator.dev/product/datta-able/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: Datta Able (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Datta Able - Modern template for Django Admin Section crafted on top of a modern Bootstrap Design.](https://user-images.githubusercontent.com/51070104/176118649-7233ffbc-6118-4f56-8cda-baa81d256877.png)

<br />

## [Datta Able PRO Version](https://app-generator.dev/product/datta-able-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-datta-pro.onrender.com/).

- **Simple, Easy-to-Extend** Codebase
- **Soft UI Design** Design - PRO Version
- Bootstrap 5 CSS
- **OAuth** - Github
- **Extended User Profile**
- **API** via DRF 
- **Charts** via ApexJS 
- **Celery** (async tasks)
- **Deployment-Ready** for Render 

![Datta Able PRO - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/170474361-a58da82b-fff9-4a59-81a8-7ab99f478f48.png)

<br />

---
**[Django Datta Able](https://app-generator.dev/docs/products/django-libs/theme-datta-able.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**
